@@ -1,38 +1,38 @@
 #include "hangul.h"
 
 static const wchar_t hangul_keyboard_table_2[] = {
-    0x0021,     /* exclam:       exclamation mark               */
-    0x0022,     /* quotedbl:     quotation mark                 */
-    0x0023,     /* numbersign:   number sign                    */
-    0x0024,     /* dollar:       dollar sign                    */
-    0x0025,     /* percent:      percent sign                   */
-    0x0026,     /* ampersand:    ampersand                      */
-    0x0027,     /* apostrophe:   apostrophe                     */
-    0x0028,     /* parenleft:    left parenthesis               */
-    0x0029,     /* parenright:   right parenthesis              */
-    0x002a,     /* asterisk:     asterisk                       */
-    0x002b,     /* plus:         plus sign                      */
-    0x002c,     /* comma:        comma                          */
-    0x002d,     /* minus:        minus sign                     */
-    0x002e,     /* period:       period                         */
-    0x002f,     /* slash:        slash                          */
-    0x0030,     /* 0:            0                              */
-    0x0031,     /* 1:            1                              */
-    0x0032,     /* 2:            2                              */
-    0x0033,     /* 3:            3                              */
-    0x0034,     /* 4:            4                              */
-    0x0035,     /* 5:            5                              */
-    0x0036,     /* 6:            6                              */
-    0x0037,     /* 7:            7                              */
-    0x0038,     /* 8:            8                              */
-    0x0039,     /* 9:            9                              */
-    0x003a,     /* colon:        colon                          */
-    0x003b,     /* semicolon:    semicolon                      */
-    0x003c,     /* less:         less-than sign                 */
-    0x003d,     /* equal:        equals sign                    */
-    0x003e,     /* greater:      greater-than sign              */
-    0x003f,     /* question:     question mark                  */
-    0x0040,     /* at:           commercial at                  */
+    0x0000,     /* exclam:       exclamation mark               */
+    0x0000,     /* quotedbl:     quotation mark                 */
+    0x0000,     /* numbersign:   number sign                    */
+    0x0000,     /* dollar:       dollar sign                    */
+    0x0000,     /* percent:      percent sign                   */
+    0x0000,     /* ampersand:    ampersand                      */
+    0x0000,     /* apostrophe:   apostrophe                     */
+    0x0000,     /* parenleft:    left parenthesis               */
+    0x0000,     /* parenright:   right parenthesis              */
+    0x0000,     /* asterisk:     asterisk                       */
+    0x0000,     /* plus:         plus sign                      */
+    0x0000,     /* comma:        comma                          */
+    0x0000,     /* minus:        minus sign                     */
+    0x0000,     /* period:       period                         */
+    0x0000,     /* slash:        slash                          */
+    0x0000,     /* 0:            0                              */
+    0x0000,     /* 1:            1                              */
+    0x0000,     /* 2:            2                              */
+    0x0000,     /* 3:            3                              */
+    0x0000,     /* 4:            4                              */
+    0x0000,     /* 5:            5                              */
+    0x0000,     /* 6:            6                              */
+    0x0000,     /* 7:            7                              */
+    0x0000,     /* 8:            8                              */
+    0x0000,     /* 9:            9                              */
+    0x0000,     /* colon:        colon                          */
+    0x0000,     /* semicolon:    semicolon                      */
+    0x0000,     /* less:         less-than sign                 */
+    0x0000,     /* equal:        equals sign                    */
+    0x0000,     /* greater:      greater-than sign              */
+    0x0000,     /* question:     question mark                  */
+    0x0000,     /* at:           commercial at                  */
     0x1106,     /* A:            choseong mieum                 */
     0x1172,     /* B:            jungseong yu                   */
     0x110e,     /* C:            choseong chieuch               */
@@ -59,12 +59,12 @@ static const wchar_t hangul_keyboard_table_2[] = {
     0x1110,     /* X:            choseong thieuth               */
     0x116d,     /* Y:            jungseong yo                   */
     0x110f,     /* Z:            choseong khieukh               */
-    0x005b,     /* bracketleft:  left bracket                   */
-    0x005c,     /* backslash:    backslash                      */
-    0x005d,     /* bracketright: right bracket                  */
-    0x005e,     /* asciicircum:  circumflex accent              */
-    0x005f,     /* underscore:   underscore                     */
-    0x0060,     /* quoteleft:    grave accent                   */
+    0x0000,     /* bracketleft:  left bracket                   */
+    0x0000,     /* backslash:    backslash                      */
+    0x0000,     /* bracketright: right bracket                  */
+    0x0000,     /* asciicircum:  circumflex accent              */
+    0x0000,     /* underscore:   underscore                     */
+    0x0000,     /* quoteleft:    grave accent                   */
     0x1106,     /* a:            choseong  mieum                */
     0x1172,     /* b:            jungseong yu                   */
     0x110e,     /* c:            choseong  chieuch              */
@@ -91,45 +91,45 @@ static const wchar_t hangul_keyboard_table_2[] = {
     0x1110,     /* x:            choseong  thieuth              */
     0x116d,     /* y:            jungseong yo                   */
     0x110f,     /* z:            choseong  khieukh              */
-    0x007b,     /* braceleft:    left brace                     */
-    0x007c,     /* bar:          vertical bar                   */
-    0x007d,     /* braceright:   right brace                    */
-    0x007e      /* asciitilde:   tilde                          */
+    0x0000,     /* braceleft:    left brace                     */
+    0x0000,     /* bar:          vertical bar                   */
+    0x0000,     /* braceright:   right brace                    */
+    0x0000      /* asciitilde:   tilde                          */
 };
 
 static const wchar_t hangul_keyboard_table_32[] = {
-    0x0021,	/* exclam:	exclamation mark		*/
-    0x0022,	/* quotedbl:	quotation mark 			*/
-    0x0023,	/* numbersign:	number sign	 		*/
-    0x0024,	/* dollar:	dollar sign			*/
-    0x0025,	/* percent:	percent sign			*/
-    0x0026,	/* ampersand:	ampersand		 	*/
-    0x0027,	/* apostrophe:	apostrophe			*/
-    0x0028,	/* parenleft:	left parenthesis		*/
-    0x0029,	/* parenright:	right parenthesis		*/
-    0x002a,	/* asterisk:	asterisk			*/
-    0x002b,	/* plus:	plus sign			*/
-    0x002c,	/* comma:	comma				*/
-    0x002d,	/* minus:	minus sign			*/
-    0x002e,	/* period:	period				*/
-    0x002f,	/* slash:	slash				*/
-    0x0030,	/* 0:		0				*/
-    0x0031,	/* 1:		1				*/
-    0x0032,	/* 2:		2				*/
-    0x0033,	/* 3:		3				*/
-    0x0034,	/* 4:		4				*/
-    0x0035,	/* 5:		5				*/
-    0x0036,	/* 6:		6				*/
-    0x0037,	/* 7:		7				*/
-    0x0038,	/* 8:		8				*/
-    0x0039,	/* 9:		9				*/
-    0x003a,	/* colon:	colon				*/
-    0x003b,	/* semicolon:	semicolon			*/
-    0x003c,	/* less:	less-than sign			*/
-    0x003d,	/* equal:	equals sign			*/
-    0x003e,	/* greater:	greater-than sign		*/
-    0x003f,	/* question:	question mark	 		*/
-    0x0040,	/* at:		commercial at			*/
+    0x0000,	/* exclam:	exclamation mark		*/
+    0x0000,	/* quotedbl:	quotation mark 			*/
+    0x0000,	/* numbersign:	number sign	 		*/
+    0x0000,	/* dollar:	dollar sign			*/
+    0x0000,	/* percent:	percent sign			*/
+    0x0000,	/* ampersand:	ampersand		 	*/
+    0x0000,	/* apostrophe:	apostrophe			*/
+    0x0000,	/* parenleft:	left parenthesis		*/
+    0x0000,	/* parenright:	right parenthesis		*/
+    0x0000,	/* asterisk:	asterisk			*/
+    0x0000,	/* plus:	plus sign			*/
+    0x0000,	/* comma:	comma				*/
+    0x0000,	/* minus:	minus sign			*/
+    0x0000,	/* period:	period				*/
+    0x0000,	/* slash:	slash				*/
+    0x0000,	/* 0:		0				*/
+    0x0000,	/* 1:		1				*/
+    0x0000,	/* 2:		2				*/
+    0x0000,	/* 3:		3				*/
+    0x0000,	/* 4:		4				*/
+    0x0000,	/* 5:		5				*/
+    0x0000,	/* 6:		6				*/
+    0x0000,	/* 7:		7				*/
+    0x0000,	/* 8:		8				*/
+    0x0000,	/* 9:		9				*/
+    0x0000,	/* colon:	colon				*/
+    0x0000,	/* semicolon:	semicolon			*/
+    0x0000,	/* less:	less-than sign			*/
+    0x0000,	/* equal:	equals sign			*/
+    0x0000,	/* greater:	greater-than sign		*/
+    0x0000,	/* question:	question mark	 		*/
+    0x0000,	/* at:		commercial at			*/
     0x11b7,	/* A:		jongseong mieum			*/
     0x1172,	/* B:		jungseong yu			*/
     0x11be,	/* C:		jongseong chieuch		*/
@@ -156,12 +156,12 @@ static const wchar_t hangul_keyboard_table_32[] = {
     0x11c0,	/* X:		jongseong thieuth		*/
     0x116d,	/* Y:		jungseong yo			*/
     0x11bf,	/* Z:		jongseong khieukh		*/
-    0x002a,	/* bracketleft:	left bracket			*/
-    0x005c,	/* backslash:	backslash			*/
-    0x005d,	/* bracketright:right bracket			*/
-    0x005e,	/* asciicircum:	circumflex accent		*/
-    0x005f,	/* underscore:	underscore			*/
-    0x0060,	/* quoteleft:	grave accent			*/
+    0x0000,	/* bracketleft:	left bracket			*/
+    0x0000,	/* backslash:	backslash			*/
+    0x0000,	/* bracketright:right bracket			*/
+    0x0000,	/* asciicircum:	circumflex accent		*/
+    0x0000,	/* underscore:	underscore			*/
+    0x0000,	/* quoteleft:	grave accent			*/
     0x1106,	/* a:		choseong  mieum			*/
     0x1172,	/* b:		jungseong yu			*/
     0x110e,	/* c:		choseong  chieuch		*/
@@ -188,27 +188,27 @@ static const wchar_t hangul_keyboard_table_32[] = {
     0x1110,	/* x:		choseong  thieuth		*/
     0x116d,	/* y:		jungseong yo			*/
     0x110f,	/* z:		choseong  khieukh		*/
-    0x007b,	/* braceleft:	left brace			*/
-    0x007c,	/* bar:		vertical bar			*/
-    0x007d,	/* braceright:	right brace			*/
+    0x0000,	/* braceleft:	left brace			*/
+    0x0000,	/* bar:		vertical bar			*/
+    0x0000,	/* braceright:	right brace			*/
     0x203b,	/* asciitilde:	tilde				*/
 };
 
 static const wchar_t hangul_keyboard_table_390[] = {
     0x11bd,	/* exclam:		jongseong cieuc			*/
-    0x0022,	/* quotedbl:	quotatioin mark			*/
-    0x0023,	/* numbersign:	number sign	 		*/
-    0x0024,	/* dollar:		dollar sign			*/
-    0x0025,	/* percent:		percent sign			*/
-    0x0026,	/* ampersand:	ampersand		 	*/
+    0x0000,	/* quotedbl:	quotatioin mark			*/
+    0x0000,	/* numbersign:	number sign	 		*/
+    0x0000,	/* dollar:		dollar sign			*/
+    0x0000,	/* percent:		percent sign			*/
+    0x0000,	/* ampersand:	ampersand		 	*/
     0x1110,	/* apostrophe:	choseong thieuth		*/
-    0x0028,	/* parenleft:	left parenthesis		*/
-    0x0029,	/* parenright:	right parenthesis		*/
-    0x002a,	/* asterisk:	asterisk			*/
-    0x002b,	/* plus:		plus sign			*/
-    0x002c,	/* comma:		comma				*/
-    0x002d,	/* minus:		minus sign			*/
-    0x002e,	/* period:		period				*/
+    0x0000,	/* parenleft:	left parenthesis		*/
+    0x0000,	/* parenright:	right parenthesis		*/
+    0x0000,	/* asterisk:	asterisk			*/
+    0x0000,	/* plus:		plus sign			*/
+    0x0000,	/* comma:		comma				*/
+    0x0000,	/* minus:		minus sign			*/
+    0x0000,	/* period:		period				*/
     0x1169,	/* slash:		jungseong o			*/
     0x110f,	/* 0:		choseong  khieukh		*/
     0x11c2,	/* 1:		jongseong hieuh			*/
@@ -220,13 +220,13 @@ static const wchar_t hangul_keyboard_table_390[] = {
     0x1168,	/* 7:		jungseong ye			*/
     0x1174,	/* 8:		jungseong yi			*/
     0x116e,	/* 9:		jungseong u			*/
-    0x003a,	/* colon:		colon				*/
+    0x0000,	/* colon:		colon				*/
     0x1107,	/* semicolon:	choseong  pieup			*/
     0x0032,	/* less:		2				*/
-    0x003d,	/* equal:		euals sign			*/
+    0x0000,	/* equal:		euals sign			*/
     0x0033,	/* greater:		3				*/
-    0x003f,	/* question:	question mark	 		*/
-    0x0040,	/* at:		commertial at			*/
+    0x0000,	/* question:	question mark	 		*/
+    0x0000,	/* at:		commertial at			*/
     0x11ae,	/* A:		jongseong tikeut		*/
     0x0021,	/* B:		exclamation mark		*/
     0x11b1,	/* C:		jongseong rieul-mieum		*/
@@ -253,12 +253,12 @@ static const wchar_t hangul_keyboard_table_390[] = {
     0x11b9,	/* X:		jongseong pieup-sios		*/
     0x003c,	/* Y:		less-than sign			*/
     0x11be,	/* Z:		jongseong chieuch		*/
-    0x005b,	/* bracketleft:	left bracket			*/
-    0x005c,	/* backslash:	backslash			*/
-    0x005d,	/* bracketright:	right bracket			*/
-    0x005e,	/* asciicircum:	circumflex accent		*/
-    0x005f,	/* underscore:	underscore			*/
-    0x0060,	/* quoteleft:	grave accent			*/
+    0x0000,	/* bracketleft:	left bracket			*/
+    0x0000,	/* backslash:	backslash			*/
+    0x0000,	/* bracketright:	right bracket			*/
+    0x0000,	/* asciicircum:	circumflex accent		*/
+    0x0000,	/* underscore:	underscore			*/
+    0x0000,	/* quoteleft:	grave accent			*/
     0x11bc,	/* a:		jongseong ieung			*/
     0x116e,	/* b:		jungseong u			*/
     0x1166,	/* c:		jungseong e			*/
@@ -285,10 +285,10 @@ static const wchar_t hangul_keyboard_table_390[] = {
     0x11a8,	/* x:		jongseong kiyeok		*/
     0x1105,	/* y:		choseong  rieul			*/
     0x11b7,	/* z:		jongseong mieum			*/
-    0x007b,	/* braceleft:	left brace			*/
-    0x007c,	/* bar:		vertical line(bar)		*/
-    0x007d,	/* braceright:	right brace			*/
-    0x007e,	/* asciitilde:	tilde				*/
+    0x0000,	/* braceleft:	left brace			*/
+    0x0000,	/* bar:		vertical line(bar)		*/
+    0x0000,	/* braceright:	right brace			*/
+    0x0000,	/* asciitilde:	tilde				*/
 };
 
 static const wchar_t hangul_keyboard_table_3final[] = {
@@ -302,10 +302,10 @@ static const wchar_t hangul_keyboard_table_3final[] = {
     0x0027,	/* parenleft:	apostrophe			*/
     0x007e,	/* parenright:	Tilde				*/
     0x201d,	/* asterisk:	right double quotation mark	*/
-    0x002b,	/* plus:		plus sign			*/
-    0x002c,	/* comma:		comma				*/
+    0x0000,	/* plus:		plus sign			*/
+    0x0000,	/* comma:		comma				*/
     0x0029,	/* minus:		right parenthesis		*/
-    0x002e,	/* period:		period				*/
+    0x0000,	/* period:		period				*/
     0x1169,	/* slash:		jungseong o			*/
     0x110f,	/* 0:		choseong  khieukh		*/
     0x11c2,	/* 1:		jongseong hieuh			*/
@@ -389,20 +389,20 @@ static const wchar_t hangul_keyboard_table_3final[] = {
 };
 
 static const wchar_t hangul_keyboard_table_3sun[] = {
-    0x0021,	/* exclam:		exclamation mark		*/
-    0x0022,	/* quotedbl:	quotatioin mark			*/
-    0x0023,	/* numbersign:	number sign	 		*/
-    0x0024,	/* dollar:		dollar sign			*/
-    0x0025,	/* percent:		percent sign			*/
-    0x0026,	/* ampersand:	ampersand		 	*/
+    0x0000,	/* exclam:		exclamation mark		*/
+    0x0000,	/* quotedbl:	quotatioin mark			*/
+    0x0000,	/* numbersign:	number sign	 		*/
+    0x0000,	/* dollar:		dollar sign			*/
+    0x0000,	/* percent:		percent sign			*/
+    0x0000,	/* ampersand:	ampersand		 	*/
     0x1110,	/* apostrophe:	choseong thieuth		*/
-    0x0028,	/* parenleft:	left parenthesis		*/
-    0x0029,	/* parenright:	right parenthesis		*/
-    0x002a,	/* asterisk:	asterisk			*/
-    0x002b,	/* plus:		plus sign			*/
-    0x002c,	/* comma:		comma				*/
+    0x0000,	/* parenleft:	left parenthesis		*/
+    0x0000,	/* parenright:	right parenthesis		*/
+    0x0000,	/* asterisk:	asterisk			*/
+    0x0000,	/* plus:		plus sign			*/
+    0x0000,	/* comma:		comma				*/
     0x11bd,	/* minus:		jongseong cieuc			*/
-    0x002e,	/* period:		period				*/
+    0x0000,	/* period:		period				*/
     0x11ae,	/* slash:		jongseong tikeut		*/
     0x1164,	/* 0:		choseong  yae			*/
     0x11c2,	/* 1:		jongseong hieuh			*/
@@ -414,13 +414,13 @@ static const wchar_t hangul_keyboard_table_3sun[] = {
     0x1168,	/* 7:		jungseong ye			*/
     0x1174,	/* 8:		jungseong yi			*/
     0x110f,	/* 9:		choseong khieukh		*/
-    0x003a,	/* colon:		colon				*/
+    0x0000,	/* colon:		colon				*/
     0x1107,	/* semicolon:	choseong  pieup			*/
     0x0032,	/* less:		2				*/
     0x11be,	/* equal:		jongseong chieuch		*/
     0x0033,	/* greater:		3				*/
-    0x003f,	/* question:	question mark	 		*/
-    0x0040,	/* at:		commertial at			*/
+    0x0000,	/* question:	question mark	 		*/
+    0x0000,	/* at:		commertial at			*/
     0x11bc,	/* A:		jongseong ieung			*/
     0x0021,	/* B:		exclamation mark		*/
     0x005c,	/* C:		backslash			*/
@@ -450,9 +450,9 @@ static const wchar_t hangul_keyboard_table_3sun[] = {
     0x11c0,	/* bracketleft:	jongseong thieuth		*/
     0x11bf,	/* backslash:	jongseong khieukh		*/
     0x11c1,	/* bracketright:	jongseong phieuph		*/
-    0x005e,	/* asciicircum:	circumflex accent		*/
-    0x005f,	/* underscore:	underscore			*/
-    0x0060,	/* quoteleft:	grave accent			*/
+    0x0000,	/* asciicircum:	circumflex accent		*/
+    0x0000,	/* underscore:	underscore			*/
+    0x0000,	/* quoteleft:	grave accent			*/
     0x11bc,	/* a:		jongseong ieung			*/
     0x116e,	/* b:		jungseong u			*/
     0x1166,	/* c:		jungseong e			*/
@@ -479,27 +479,27 @@ static const wchar_t hangul_keyboard_table_3sun[] = {
     0x11a8,	/* x:		jongseong kiyeok		*/
     0x1105,	/* y:		choseong  rieul			*/
     0x11b7,	/* z:		jongseong mieum			*/
-    0x007b,	/* braceleft:	left brace			*/
-    0x007c,	/* bar:		vertical line(bar)		*/
-    0x007d,	/* braceright:	right brace			*/
-    0x007e,	/* asciitilde:	tilde				*/
+    0x0000,	/* braceleft:	left brace			*/
+    0x0000,	/* bar:		vertical line(bar)		*/
+    0x0000,	/* braceright:	right brace			*/
+    0x0000,	/* asciitilde:	tilde				*/
 };
 
 static const wchar_t hangul_keyboard_table_3yet[] = {
     0x11bd,	/* exclam:		jongseong cieuc			*/
-    0x0022,	/* quotedbl:	quotatioin mark			*/
-    0x0023,	/* numbersign:	number sign	 		*/
-    0x0024,	/* dollar:		dollar sign			*/
-    0x0025,	/* percent:		percent sign			*/
-    0x0026,	/* ampersand:	ampersand		 	*/
+    0x0000,	/* quotedbl:	quotatioin mark			*/
+    0x0000,	/* numbersign:	number sign	 		*/
+    0x0000,	/* dollar:		dollar sign			*/
+    0x0000,	/* percent:		percent sign			*/
+    0x0000,	/* ampersand:	ampersand		 	*/
     0x1110,	/* apostrophe:	choseong thieuth		*/
-    0x0028,	/* parenleft:	left parenthesis		*/
-    0x0029,	/* parenright:	right parenthesis		*/
-    0x002a,	/* asterisk:	asterisk			*/
-    0x002b,	/* plus:		plus sign			*/
-    0x002c,	/* comma:		comma				*/
-    0x002d,	/* minus:		minus sign			*/
-    0x002e,	/* period:		period				*/
+    0x0000,	/* parenleft:	left parenthesis		*/
+    0x0000,	/* parenright:	right parenthesis		*/
+    0x0000,	/* asterisk:	asterisk			*/
+    0x0000,	/* plus:		plus sign			*/
+    0x0000,	/* comma:		comma				*/
+    0x0000,	/* minus:		minus sign			*/
+    0x0000,	/* period:		period				*/
     0x1169,	/* slash:		jungseong o			*/
     0x110f,	/* 0:		choseong  khieukh		*/
     0x11c2,	/* 1:		jongseong hieuh			*/
@@ -511,12 +511,12 @@ static const wchar_t hangul_keyboard_table_3yet[] = {
     0x1168,	/* 7:		jungseong ye			*/
     0x1174,	/* 8:		jungseong yi			*/
     0x116e,	/* 9:		jungseong u			*/
-    0x003a,	/* colon:		colon				*/
+    0x0000,	/* colon:		colon				*/
     0x1107,	/* semicolon:	choseong  pieup			*/
     0x113c,	/* less:		choseong chitueumsios		*/
-    0x003d,	/* equal:		euals sign			*/
+    0x0000,	/* equal:		euals sign			*/
     0x113e,	/* greater:		choseong ceongchieumsios	*/
-    0x003f,	/* question:	question mark	 		*/
+    0x0000,	/* question:	question mark	 		*/
     0x11eb,	/* at:		jongseong pansios		*/
     0x11ae,	/* A:		jongseong tikeut		*/
     0x116e,	/* B:		jungseong u			*/
@@ -544,11 +544,11 @@ static const wchar_t hangul_keyboard_table_3yet[] = {
     0x11b9,	/* X:		jongseong pieup-sios		*/
     0x302f,	/* Y:		double dot tone mark		*/
     0x11be,	/* Z:		jongseong chieuch		*/
-    0x005b,	/* bracketleft:	left bracket			*/
-    0x005c,	/* backslash:	backslash			*/
-    0x005d,	/* bracketright:	right bracket			*/
-    0x005e,	/* asciicircum:	circumflex accent		*/
-    0x005f,	/* underscore:	underscore			*/
+    0x0000,	/* bracketleft:	left bracket			*/
+    0x0000,	/* backslash:	backslash			*/
+    0x0000,	/* bracketright:	right bracket			*/
+    0x0000,	/* asciicircum:	circumflex accent		*/
+    0x0000,	/* underscore:	underscore			*/
     0x11f9,	/* quoteleft:	jongseong yeorinhieuh		*/
     0x11bc,	/* a:		jongseong ieung			*/
     0x116e,	/* b:		jungseong u			*/
@@ -576,9 +576,9 @@ static const wchar_t hangul_keyboard_table_3yet[] = {
     0x11a8,	/* x:		jongseong kiyeok		*/
     0x1105,	/* y:		choseong  rieul			*/
     0x11b7,	/* z:		jongseong mieum			*/
-    0x007b,	/* braceleft:	left brace			*/
-    0x007c,	/* bar:		vertical line(bar)		*/
-    0x007d,	/* braceright:	right brace			*/
+    0x0000,	/* braceleft:	left brace			*/
+    0x0000,	/* bar:		vertical line(bar)		*/
+    0x0000,	/* braceright:	right brace			*/
     0x11f0,	/* asciitilde:	jongseong yesieung		*/
 };
 
