@@ -23,7 +23,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_hangul_imengine_setup.cpp,v 1.1.1.1 2004/12/27 05:19:32 hwanjin Exp $
+ * $Id: scim_hangul_imengine_setup.cpp,v 1.2 2005/10/29 09:53:12 hwanjin Exp $
  *
  */
 
@@ -135,12 +135,10 @@ struct KeyboardConfigData
 };
 
 // Internal data declaration.
-static bool __config_use_dvorak            = false;
 static bool __config_show_candidate_comment= true;
 
 static bool __have_changed                 = false;
 
-static GtkWidget    * __widget_use_dvorak            = 0;
 static GtkWidget    * __widget_show_candidate_comment= 0;
 static GtkTooltips  * __widget_tooltips              = 0;
 
@@ -214,28 +212,17 @@ create_options_page ()
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
-    __widget_use_dvorak = gtk_check_button_new_with_mnemonic (_("Use _Dvorak keyboard"));
-    gtk_widget_show (__widget_use_dvorak);
-    gtk_box_pack_start (GTK_BOX (vbox), __widget_use_dvorak, FALSE, FALSE, 4);
-    gtk_container_set_border_width (GTK_CONTAINER (__widget_use_dvorak), 4);
-
     __widget_show_candidate_comment = gtk_check_button_new_with_mnemonic (_("_Show candidate comment"));
     gtk_widget_show (__widget_show_candidate_comment);
     gtk_box_pack_start (GTK_BOX (vbox), __widget_show_candidate_comment, FALSE, FALSE, 4);
     gtk_container_set_border_width (GTK_CONTAINER (__widget_show_candidate_comment), 4);
 
     // Connect all signals.
-    g_signal_connect ((gpointer) __widget_use_dvorak, "toggled",
-                      G_CALLBACK (on_default_toggle_button_toggled),
-                      &__config_use_dvorak);
     g_signal_connect ((gpointer) __widget_show_candidate_comment, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_show_candidate_comment);
 
     // Set all tooltips.
-    gtk_tooltips_set_tip (__widget_tooltips, __widget_use_dvorak,
-                          _("Whether to use dvorak keyboard or not."), NULL);
-
     gtk_tooltips_set_tip (__widget_tooltips, __widget_show_candidate_comment,
                           _("Whether to show the comment of candidates or not."), NULL);
 
@@ -342,12 +329,6 @@ create_setup_window ()
 void
 setup_widget_value ()
 {
-    if (__widget_use_dvorak) {
-        gtk_toggle_button_set_active (
-            GTK_TOGGLE_BUTTON (__widget_use_dvorak),
-            __config_use_dvorak);
-    }
-
     if (__widget_show_candidate_comment) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_show_candidate_comment),
@@ -367,9 +348,6 @@ void
 load_config (const ConfigPointer &config)
 {
     if (!config.null ()) {
-        __config_use_dvorak =
-            config->read (String (SCIM_CONFIG_IMENGINE_HANGUL_USE_DVORAK),
-                          __config_use_dvorak);
         __config_show_candidate_comment =
             config->read (String (SCIM_CONFIG_IMENGINE_HANGUL_SHOW_CANDIDATE_COMMENT),
                           __config_show_candidate_comment);
@@ -390,8 +368,6 @@ void
 save_config (const ConfigPointer &config)
 {
     if (!config.null ()) {
-        config->write (String (SCIM_CONFIG_IMENGINE_HANGUL_USE_DVORAK),
-                        __config_use_dvorak);
         config->write (String (SCIM_CONFIG_IMENGINE_HANGUL_SHOW_CANDIDATE_COMMENT),
                        __config_show_candidate_comment);
 
